@@ -29,8 +29,9 @@ using namespace boost::filesystem;
 //=== Config ===============================================================
 Config::Config ()
 	: m_config_file()
-	, m_od1(256)
-	, m_od2()
+	, m_od_visible(256)
+	, m_od_cmdline()
+	, m_od_cfgfile()
 	, m_pod()
 	, m_vm()
 	, m_now(second_clock::local_time())
@@ -47,8 +48,8 @@ void Config::Init (int argc, char* argv[]) throw (Xception)
 	{
 		// evaluate command line
 		command_line_parser cp(argc, argv);
-		m_od2.add(m_od1); // a bit tricky
-		cp.options(m_od2);
+		m_od_cmdline.add(m_od_visible); // a bit tricky
+		cp.options(m_od_cmdline);
 		cp.positional(m_pod);
 		parsed_options po(cp.run());
 
@@ -99,8 +100,12 @@ void Config::Init (int argc, char* argv[]) throw (Xception)
 		ifstream ifs(m_config_file.c_str(), ios::in);
 		if (ifs.good())
 		{
-			options_description od;
-			parsed_options po(&od);
+			// we still need a vector option for the defines time periods
+			// (only in the cfg file)
+			m_od_cfgfile.add_options() ("period", value<vector<string> >(), "");
+			m_pod.add("period", -1); // unlimited
+
+			parsed_options po(&m_od_cfgfile); // note: this is extending, see below
 			string line;
 			while (getline(ifs, line))
 			{
@@ -117,26 +122,34 @@ void Config::Init (int argc, char* argv[]) throw (Xception)
 					if (!option_value.empty() && option_value[option_value.length() - 1] == '"')
 						option_value.erase(option_value.length() - 1, 1);
 
-					if (od.find_nothrow(option_name, false))
+					bool found = false;
+					if (m_od_cfgfile.find_nothrow(option_name, false))
 					{
 						foreach (option& o, po.options)
 						{
 							if (o.string_key == option_name)
 							{
 								o.value.push_back(option_value);
+								found = true;
 								break;
 							}
 						}
 					}
-					else
+
+					if (!found)
 					{
-						od.add_options() (option_name.c_str(), value<string>(), "");
+						// we extend m_od_cfgfile for every "unknown" option
+						if (!m_od_cfgfile.find_nothrow(option_name, false))
+							m_od_cfgfile.add_options() (option_name.c_str(), value<string>(), "");
 						vector<string> values;
 						values.push_back(option_value);
 						po.options.push_back(option(option_name, values));
 					}
 				}
 			}
+
+			ModifyCfgFileOptions(po);
+
 			store(po, m_vm);
 		}
 
@@ -145,27 +158,23 @@ void Config::Init (int argc, char* argv[]) throw (Xception)
 		// check if we have a -n parameter
 		const string& n = GetStringOption("now");
 		if (!n.empty())
-		{                          //  CCYY     -MM      -DD     [-hh         :mm        [:ss]]
-			static const regex rx("([0-9]+)(-[0-9]+)(-[0-9]+)(-[0-9]+)?(\\:[0-9]+)?(\\:[0-9]+)?");
+		{                          //  CCYY     -MM      -DD     [-hh      :mm      [:ss]]
+			static const regex rx("([0-9]+)(-[0-9]+)(-[0-9]+)(-[0-9]+\\:[0-9]+(\\:[0-9]+)?)?");
 			smatch mr;
 			regex_match(n, mr, rx);
 
 			string t(n);
-			if (mr.length(6) > 0)
+			if (mr.length(5) > 0)
 				;
 			else
 			{
-				if (mr.length(5) > 0)
+				if (mr.length(4) > 0)
 					t += ":00"; // add seconds
 				else
-				{
-					if (mr.length(4) > 0)
-						t += ":00:00"; // add minutes and seconds
-					else
-						t += " 00:00:00"; // add complete time
-				}
+					t += " 00:00:00"; // add complete time
 			}
 			t += ".000"; // add milliseconds
+			t[10] = ' ';
 
 			m_now = time_from_string(t);
 		}
@@ -180,9 +189,13 @@ void Config::ModifyCmdLineOptions (parsed_options& po)
 {
 }
 
+void Config::ModifyCfgFileOptions (parsed_options& po)
+{
+}
+
 void Config::Help (ostream& os) const
 {
-	m_od1.print(os);
+	m_od_visible.print(os);
 }
 
 bool Config::HasOption (const string& option) const
