@@ -86,7 +86,7 @@ void PocoDatabaseImpl::ListCollections () throw (Xception)
 		}
 		string operator () (int idx)
 		{
-			static const size_t widths[] = {6, 8, 6, 7, 20, 20}; // real column widths
+			static const size_t widths[] = {6, 8, 6, 7, 20, 20, 16}; // real column widths
 			size_t width = widths[idx];
 			string result(m_s);
 			while (result.length() < width)
@@ -99,7 +99,7 @@ void PocoDatabaseImpl::ListCollections () throw (Xception)
 
 	try
 	{
-		cout << "  " << fill("name")(0) << fill("type")(1) << fill("table")(2) << fill("recs")(3) << fill("first")(4) << fill("last")(5) << "purpose" << endl;
+		cout << "  " << fill("name")(0) << fill("type")(1) << fill("table")(2) << fill("recs")(3) << fill("first")(4) << fill("last")(5) << fill("unit")(6) << "purpose" << endl;
 
 		foreach (const CollectionMetaInfo& cmi, m_collectionMetaInfos)
 		{
@@ -120,6 +120,7 @@ void PocoDatabaseImpl::ListCollections () throw (Xception)
 			(*m_pSession) << "select count(*),min(t),max(t) from " << cmi.m_tblname << ";", into(count), into(min), into(max), now;
 			cout << fill(lexical_cast<string>(count))(3) << fill(min)(4) << fill(max)(5);
 
+			cout << fill(cmi.m_unit)(6);
 			cout << cmi.m_purpose << endl;
 		}
 	}
@@ -128,14 +129,14 @@ void PocoDatabaseImpl::ListCollections () throw (Xception)
 	}
 }
 
-void PocoDatabaseImpl::AddCollection (const string& name) throw (Xception) // "name[, n|r|t[, purpose]]"
+void PocoDatabaseImpl::AddCollection (const string& name) throw (Xception) // "name[, n|r|t[, unit[, purpose]]]"
 {
 	try
 	{
-		// split collection name, type and purpose
-		string n, t, p;
+		// split collection name, type, unit and purpose
+		string n, t, p, u;
 		{
-			regex rx("\\s*([^,\\s]+)(?:\\s*,\\s*([nrt])\\s*(?:,(.+))?)?");
+			regex rx("\\s*([^,\\s]+)(?:\\s*,\\s*([nrt])\\s*(?:,([^,]+)(?:,(.+))?)?)?");
 			smatch mr;
 			if (!regex_match(name, mr, rx))
 				throw Xception(format("illegal collection specification: %s") % name);
@@ -143,7 +144,9 @@ void PocoDatabaseImpl::AddCollection (const string& name) throw (Xception) // "n
 			t = mr[2];
 			if (t.empty())
 				t = "n"; // numeric
-			p = mr[3];
+			u = mr[3];
+			trim(u);
+			p = mr[4];
 			trim(p);
 		}
 
@@ -180,10 +183,10 @@ void PocoDatabaseImpl::AddCollection (const string& name) throw (Xception) // "n
 		const string& tblname = GetNewTblname();
 
 		// do the database specific SQL job
-		CreateCollectionInSchema(n, t[0], tblname, p);
+		CreateCollectionInSchema(n, t[0], tblname, p, u);
 
 		// create a CollectionMetaInfo
-		CollectionMetaInfo cmi = {n, t[0], tblname, p};
+		CollectionMetaInfo cmi = {n, t[0], tblname, p, u};
 		m_collectionMetaInfos.insert(cmi);
 	}
 	catch (...)
@@ -347,6 +350,11 @@ string PocoDatabaseImpl::GetCollectionPurpose (const string& name) const throw (
 	return GetCollectionMetaInfo(name).m_purpose;
 }
 
+string PocoDatabaseImpl::GetCollectionUnit (const string& name) const throw (Xception)
+{
+	return GetCollectionMetaInfo(name).m_unit;
+}
+
 void PocoDatabaseImpl::GetCollections (Collections& collections) const throw (Xception)
 {
 	foreach (const CollectionMetaInfo& cmi, m_collectionMetaInfos)
