@@ -61,7 +61,8 @@ void MySQLDatabase::NoSchemaCallback () throw (Xception)
 					"name varchar(64) not null primary key,"
 					"type char(1) not null,"
 					"tbl_name varchar(64) not null,"
-					"purpose varchar(256)"
+					"purpose varchar(256)",
+					"unit varchar(16)"
 				 ") engine=InnoDB;", now;
 
 		(*m_pSession) << "create table TRejected "
@@ -83,8 +84,8 @@ void MySQLDatabase::NoSchemaCallback () throw (Xception)
 					"v varchar(1024) not null"
 				 ") engine=InnoDB;", now;
 
-		(*m_pSession) << "insert into TCollections values ('*','n','C0',NULL);", now;
-		(*m_pSession) << "insert into TCollections values ('#','t','C1',NULL);", now;
+		(*m_pSession) << "insert into TCollections values ('*','n','C0',NULL,NULL);", now;
+		(*m_pSession) << "insert into TCollections values ('#','t','C1',NULL,NULL);", now;
 
 		transactor.Commit();
 	}
@@ -109,7 +110,22 @@ void MySQLDatabase::NoPurposeColumnCallback () throw (Xception)
 	}
 }
 
-void MySQLDatabase::CreateCollectionInSchema (const string& name, char type, const string& tblname, const string& purpose) throw (Xception)
+void MySQLDatabase::NoUnitColumnCallback () throw (Xception)
+{
+	if (m_verbose)
+		cout << "updating schema" << endl;
+
+	try
+	{
+		(*m_pSession) << "alter table TCollections add column unit varchar(16);", now;
+	}
+	catch (...)
+	{
+		throw Xception("could not update schema");
+	}
+}
+
+void MySQLDatabase::CreateCollectionInSchema (const string& name, char type, const string& tblname, const string& purpose, const string& unit) throw (Xception)
 {
 	try
 	{
@@ -129,7 +145,7 @@ void MySQLDatabase::CreateCollectionInSchema (const string& name, char type, con
 
 		string t;
 		t = type;
-		(*m_pSession) << "insert into TCollections values (?,?,?,?);", use(name), use(t), use(tblname), use(purpose), now;
+		(*m_pSession) << "insert into TCollections values (?,?,?,?,?);", use(name), use(t), use(tblname), use(purpose), use(unit), now;
 
 		transactor.Commit();
 	}
