@@ -54,7 +54,8 @@ void SQLiteDatabase::NoSchemaCallback () throw (Xception)
 					"name varchar(64) not null primary key,"
 					"type char(1) not null,"
 					"tbl_name varchar(64) not null,"
-					"purpose varchar(256)"
+					"purpose varchar(256),"
+					"unit varchar(16)"
 				 ");", now;
 
 		(*m_pSession) << "create table TRejected "
@@ -76,8 +77,8 @@ void SQLiteDatabase::NoSchemaCallback () throw (Xception)
 					"v varchar(1024) not null"
 				 ");", now;
 
-		(*m_pSession) << "insert into TCollections values ('*','n','C0',NULL);", now;
-		(*m_pSession) << "insert into TCollections values ('#','t','C1',NULL);", now;
+		(*m_pSession) << "insert into TCollections values ('*','n','C0',NULL,NULL);", now;
+		(*m_pSession) << "insert into TCollections values ('#','t','C1',NULL,NULL);", now;
 
 		transactor.Commit();
 	}
@@ -102,7 +103,22 @@ void SQLiteDatabase::NoPurposeColumnCallback () throw (Xception)
 	}
 }
 
-void SQLiteDatabase::CreateCollectionInSchema (const string& name, char type, const string& tblname, const string& purpose) throw (Xception)
+void SQLiteDatabase::NoUnitColumnCallback () throw (Xception)
+{
+	if (m_verbose)
+		cout << "updating schema" << endl;
+
+	try
+	{
+		(*m_pSession) << "alter table TCollections add column unit varchar(16);", now;
+	}
+	catch (...)
+	{
+		throw Xception("could not update schema");
+	}
+}
+
+void SQLiteDatabase::CreateCollectionInSchema (const string& name, char type, const string& tblname, const string& purpose, const string& unit) throw (Xception)
 {
 	try
 	{
@@ -122,7 +138,7 @@ void SQLiteDatabase::CreateCollectionInSchema (const string& name, char type, co
 
 		string t;
 		t = type;
-		(*m_pSession) << "insert into TCollections values (:n,:t,:tbl_name,:purpose);", use(name), use(t), use(tblname), use(purpose), now;
+		(*m_pSession) << "insert into TCollections values (:n,:t,:tbl_name,:purpose,:unit);", use(name), use(t), use(tblname), use(purpose), use(unit), now;
 
 		transactor.Commit();
 	}
