@@ -94,6 +94,7 @@ XMLFile::XMLFile (const string& option_key)
 		string m_current_collection;
 		string m_current_collection_type;
 		string m_current_collection_purpose;
+		string m_current_collection_unit;
 		Database& m_database;
 		Database::CollectionsItems& m_items;
 
@@ -118,6 +119,7 @@ XMLFile::XMLFile (const string& option_key)
 		, m_current_collection()
 		, m_current_collection_type()
 		, m_current_collection_purpose()
+		, m_current_collection_unit()
 		, m_database(database)
 		, m_items(items)
 	{
@@ -140,8 +142,9 @@ XMLFile::XMLFile (const string& option_key)
 			ch.m_current_collection = attrList.getValue(uri, "name");
 			ch.m_current_collection_type = attrList.getValue(uri, "type");
 			ch.m_current_collection_purpose = attrList.getValue(uri, "purpose");
+			ch.m_current_collection_unit = attrList.getValue(uri, "unit");
 
-			ch.m_database.AddCollection(ch.m_current_collection + ',' + ch.m_current_collection_type[0] + ',' + ch.m_current_collection_purpose);
+			ch.m_database.AddCollection(ch.m_current_collection + ',' + ch.m_current_collection_type[0] + ',' + ch.m_current_collection_purpose + ',' + ch.m_current_collection_unit);
 		}
 
 		static void pdr_collection_start_item (content_handler& ch, const XMLString& uri, const Attributes& attrList)
@@ -245,6 +248,7 @@ XMLFile::XMLFile (const string& option_key)
 			ch.m_current_collection.clear();
 			ch.m_current_collection_type.clear();
 			ch.m_current_collection_purpose.clear();
+			ch.m_current_collection_unit.clear();
 		}
 
 	void content_handler::endElement (const XMLString& uri, const XMLString& localName, const XMLString& qname)
