@@ -54,8 +54,8 @@ ConfigImpl::ConfigImpl ()
 
 		// database options
 		("list-collections,l",					"list all available collections in the database")
-		("add-collection,a", value<vector<string> >(),		"add a collection to the database, specify \"name[, n|r|t]\"")
-		("delete-collection,d", value<vector<string> >(),	"delete a collection from the database, specify \"name\"")
+		("add-collection,a", value<vector<string> >(),		"add a collection to the database, arg is a string like \"name[, n|r|t[, unit[, purpose]]]\"")
+		("delete-collection,d", value<vector<string> >(),	"delete a collection from the database, arg is a string like \"name\"")
 		("delete-all-collections,D",				"delete all collections from the database")
 		("list-rejections,r",					"list all rejected expressions")
 		("delete-all-rejections,R",				"delete all rejected expressions")
