@@ -30,7 +30,7 @@ using namespace boost::program_options;
 using namespace Poco::Data;
 
 #include "../libpdrx/datatypes.h"
-#include "../libpdrx/config.h"
+#include "config_impl.h"
 #include "db_impl.h"
 
 //=== MySQLDatabase ========================================================
