@@ -24,8 +24,8 @@ using namespace boost::program_options;
 using namespace boost::filesystem;
 
 #include "../libpdrx/datatypes.h"
-#include "../libpdrx/config.h"
 #include "../libpdrx/encoding.h"
+#include "config_impl.h"
 #include "diagram_impl.h"
 
 //=== Diagram ==============================================================
@@ -79,13 +79,19 @@ Diagram* DiagramFactory::Create (const string& filename, bool antialias) throw (
 	const string& ext = path(filename).extension();
 
 #ifdef USE_BOARD
-	if (ext == ".svg")
+	if (ext == ".svg" || ext == ".SVG")
 		return new DiagramSVG();
+
+	if (ext == ".eps" || ext == ".EPS")
+		return new DiagramEPS();
+
+	if (ext == ".fig" || ext == ".FIG")
+		return new DiagramXFig();
 #endif // USE_BOARD
 
 #ifdef USE_CAIRO
-	if (ext == ".png")
-		return new DiagramCairo(antialias);
+	if (ext == ".png" || ext == ".PNG")
+		return new DiagramPNG(antialias);
 #endif // USE_CAIRO
 
 	// ...
