@@ -45,7 +45,7 @@ void DiagramImpl::SetSundaysColor (RGB color)
 	m_sundays = color;
 }
 
-void DiagramImpl::DrawAxes (const ptime& x_min, const ptime& x_max, XUnit x_unit, double y_min, double y_max, double y_unit, RGB color, const ConfigImpl::Periods& /*periods*/)
+void DiagramImpl::DrawAxes (const ptime& x_min, const ptime& x_max, XUnit x_unit, double y_min, double y_max, double y_unit, RGB color, const string& text, const ConfigImpl::Periods& /*periods*/)
 {
 	m_xmin = x_min;
 	m_xmax = x_max;
@@ -65,7 +65,7 @@ void DiagramImpl::DrawAxes (const ptime& x_min, const ptime& x_max, XUnit x_unit
 	}
 }
 
-void DiagramImpl::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_max, double y_unit, RGB color)
+void DiagramImpl::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_max, double y_unit, RGB color, const string& text)
 {
 	// for folding we must handle dates in the year 9999, this is a bit
 	// special but indeed no problem, we just need an according axis
