@@ -40,6 +40,7 @@ BoardDiagram::BoardDiagram ()
 	: DiagramImpl()
 	, m_canvas()
 	, m_shapes()
+	, m_background(0x00FFFFFF)
 {
 	m_diagram.width = m_diagram.height = 0.0;
 	m_canvas.setUnit(Board::UPoint);
@@ -52,8 +53,9 @@ void BoardDiagram::OpenCanvas (size_t width, size_t height, RGB bgColor)
 
 	m_diagram.width = width;
 	m_diagram.height = height;
+	m_background = bgColor;
 
-	m_canvas.clear(COLOR(bgColor));
+	m_canvas.clear(COLOR(m_background));
 }
 
 void BoardDiagram::CloseCanvas ()
@@ -61,9 +63,9 @@ void BoardDiagram::CloseCanvas ()
 	m_canvas << m_shapes;
 }
 
-void BoardDiagram::DrawAxes (const ptime& x_min, const ptime& x_max, XUnit x_unit, double y_min, double y_max, double y_unit, RGB color, const ConfigImpl::Periods& periods)
+void BoardDiagram::DrawAxes (const ptime& x_min, const ptime& x_max, XUnit x_unit, double y_min, double y_max, double y_unit, RGB color, const string& text, const ConfigImpl::Periods& periods)
 {
-	DiagramImpl::DrawAxes(x_min, x_max, x_unit, y_min, y_max, y_unit, color, periods);
+	DiagramImpl::DrawAxes(x_min, x_max, x_unit, y_min, y_max, y_unit, color, text, periods);
 
 	// Note: libboard doesn't compute real dimensions for text, if we
 	// put text on a shape and ask the shape about the size of the text
@@ -175,19 +177,37 @@ void BoardDiagram::DrawAxes (const ptime& x_min, const ptime& x_max, XUnit x_uni
 
 	const double dash_width = m_diagram.width / 100.0; // one percent of m_diagram.width
 
+	double left = x_0;
+	double top = CalcY(y_max);
 	const string& yf = FormatY();
 	for (double t = m_ymin; t <= m_ymax; t += m_yunit)
 	{
+		double x = x_0 - dash_width;
 		double y = CalcY(t);
-		m_shapes << Line(x_0 - dash_width, y, x_0, y, COLOR(color), LINE_THICKNESS);
+		m_shapes << Line(x, y, x_0, y, COLOR(color), LINE_THICKNESS);
+
 		string s((format(yf) % t).str());
-		m_shapes << Text(x_0 - dash_width - (s.length() * char_width), y - (char_height / 2.0), s, Fonts::Helvetica, font_size, COLOR(color));
+		x -= (s.length() * char_width);
+		y -= (char_height / 2.0);
+		m_shapes << Text(x, y, s, Fonts::Helvetica, font_size, COLOR(color));
+
+		if (left > x)
+			left = x;
+		if (top < y + char_height)
+			top = y + char_height;
+	}
+
+	// text above the y-axis
+	if (!text.empty())
+	{
+		m_shapes << LibBoard::Dot(left, top + char_height + 6.0, COLOR(m_background), (float)1.0);
+		m_shapes << Text(left, top + 5.0, text, Fonts::Helvetica, font_size, COLOR(color));
 	}
 }
 
-void BoardDiagram::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_max, double y_unit, RGB color)
+void BoardDiagram::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_max, double y_unit, RGB color, const string& text)
 {
-	DiagramImpl::DrawAxes(fi, y_min, y_max, y_unit, color);
+	DiagramImpl::DrawAxes(fi, y_min, y_max, y_unit, color, text);
 
 	// Note: libboard doesn't compute real dimensions for text, if we
 	// put text on a shape and ask the shape about the size of the text
@@ -244,13 +264,31 @@ void BoardDiagram::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_ma
 
 	const double dash_width = m_diagram.width / 100.0; // one percent of m_diagram.width
 
+	double left = x_0;
+	double top = CalcY(y_max);
 	const string& yf = FormatY();
 	for (double t = m_ymin; t <= m_ymax; t += m_yunit)
 	{
+		double x = x_0 - dash_width;
 		double y = CalcY(t);
-		m_shapes << Line(x_0 - dash_width, y, x_0, y, COLOR(color), LINE_THICKNESS);
+		m_shapes << Line(x, y, x_0, y, COLOR(color), LINE_THICKNESS);
+
 		string s((format(yf) % t).str());
-		m_shapes << Text(x_0 - dash_width - (s.length() * char_width), y - (char_height / 2.0), s, Fonts::Helvetica, font_size, COLOR(color));
+		x -= (s.length() * char_width);
+		y -= (char_height / 2.0);
+		m_shapes << Text(x, y, s, Fonts::Helvetica, font_size, COLOR(color));
+
+		if (left > x)
+			left = x;
+		if (top < y + char_height)
+			top = y + char_height;
+	}
+
+	// text above the y-axis
+	if (!text.empty())
+	{
+		m_shapes << LibBoard::Dot(left, top + char_height + 6.0, COLOR(m_background), (float)1.0);
+		m_shapes << Text(left, top + 5.0, text, Fonts::Helvetica, font_size, COLOR(color));
 	}
 }
 
