@@ -90,6 +90,7 @@ void CairoDiagram::OpenCanvas (size_t width, size_t height, RGB bgColor)
 		cairo_text_extents(pContext, " CCCC-MM-DD hh:mm:ss ", &extents);
 		m_margin.left = m_margin.bottom = extents.width;
 		m_margin.right = m_margin.top = extents.height / 2.0 + 1.0;
+		m_margin.top += extents.height + 5; // for the text above the y-axis
 
 		cairo_destroy(pContext);
 		cairo_surface_destroy(pSurface);
@@ -109,13 +110,13 @@ void CairoDiagram::OpenCanvas (size_t width, size_t height, RGB bgColor)
 	m_pContext = cairo_create(m_pSurface);
 
 	// set some over all properties
-	if (!m_antialias)
-		cairo_set_antialias(m_pContext, CAIRO_ANTIALIAS_NONE);
+	cairo_antialias_t aa = (m_antialias) ? CAIRO_ANTIALIAS_DEFAULT : CAIRO_ANTIALIAS_NONE;
+	cairo_set_antialias(m_pContext, aa);
 
 	cairo_set_font_size(m_pContext, width / 40);
 	cairo_font_options_t* pOptions = cairo_font_options_create();
 	cairo_get_font_options(m_pContext, pOptions);
-	cairo_font_options_set_antialias(pOptions, CAIRO_ANTIALIAS_NONE);
+	cairo_font_options_set_antialias(pOptions, aa);
 	cairo_set_font_options(m_pContext, pOptions);
 	cairo_font_options_destroy(pOptions);
 
@@ -155,9 +156,9 @@ void CairoDiagram::CloseCanvas ()
 	m_pSurface = pSurface;
 }
 
-void CairoDiagram::DrawAxes (const ptime& x_min, const ptime& x_max, XUnit x_unit, double y_min, double y_max, double y_unit, RGB color, const ConfigImpl::Periods& periods)
+void CairoDiagram::DrawAxes (const ptime& x_min, const ptime& x_max, XUnit x_unit, double y_min, double y_max, double y_unit, RGB color, const string& text, const ConfigImpl::Periods& periods)
 {
-	DiagramImpl::DrawAxes(x_min, x_max, x_unit, y_min, y_max, y_unit, color, periods);
+	DiagramImpl::DrawAxes(x_min, x_max, x_unit, y_min, y_max, y_unit, color, text, periods);
 
 	const double x_0 = CalcX(m_xmin);
 	const double y_0 = CalcY(m_ymin);
@@ -287,12 +288,22 @@ void CairoDiagram::DrawAxes (const ptime& x_min, const ptime& x_max, XUnit x_uni
 		text_y(x_0, y, dash_width, s);
 	}
 
+	// text above the y-axis
+	if (!text.empty())
+	{
+		cairo_text_extents_t extents;
+		cairo_text_extents(m_pContext, text.c_str(), &extents);
+		move_to(m_origin.x, CalcY(y_max) - (extents.height / 2) - 5);
+		UpdateOrigin(m_origin.x, CalcY(y_max) + (extents.height / 2) + 5);
+		cairo_show_text(m_pContext, text.c_str());
+	}
+
 	cairo_stroke(m_pContext);
 }
 
-void CairoDiagram::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_max, double y_unit, RGB color)
+void CairoDiagram::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_max, double y_unit, RGB color, const string& text)
 {
-	DiagramImpl::DrawAxes(fi, y_min, y_max, y_unit, color);
+	DiagramImpl::DrawAxes(fi, y_min, y_max, y_unit, color, text);
 
 	const double x_0 = CalcX(m_xmin);
 	const double y_0 = CalcY(m_ymin);
@@ -360,6 +371,16 @@ void CairoDiagram::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_ma
 		text_y(x_0, y, dash_width, s);
 	}
 
+	// text above the y-axis
+	if (!text.empty())
+	{
+		cairo_text_extents_t extents;
+		cairo_text_extents(m_pContext, text.c_str(), &extents);
+		move_to(m_origin.x, CalcY(y_max) - (extents.height / 2) - 5);
+		UpdateOrigin(m_origin.x, CalcY(y_max) + (extents.height / 2) + 5);
+		cairo_show_text(m_pContext, text.c_str());
+	}
+
 	cairo_stroke(m_pContext);
 }
 
