@@ -23,7 +23,7 @@ using namespace boost::gregorian;
 using namespace boost::program_options;
 
 #include "../libpdrx/datatypes.h"
-#include "../libpdrx/config.h"
+#include "config_impl.h"
 #include "db.h"
 #include "out_impl.h"
 #include "out_ftree.h"
